@@ -3,7 +3,7 @@ package Release::Checklist;
 use strict;
 use warnings;
 
-our $VERSION = "0.10";
+our $VERSION = "0.12";
 
 1;
 
@@ -33,7 +33,9 @@ Each subject will mention or list modules that might help in improving
 or preserving high standards.
 
 Various guidelines are also available in the
-L<perl core documentation|https://perldoc.perl.org/perlmodstyle.html>
+L<perl core documentation|https://perldoc.perl.org/perlmodstyle.html> and
+the basics for preparing a (new) module for distribution can be found in
+L<perlnewmod|https://perldoc.perl.org/perlnewmod.html>.
 
   $ perldoc perlmodstyle
 
@@ -48,11 +50,11 @@ will break your code with small changes.
   :
   done_testing ();
 
-Separate your module tests and your author tests. This will lower
-the number of dependencies. Check your Pod syntax, documentation
-coverage, spelling, and minimum perl version requirements in C<xt/>.
-There is no need to check that when the distribution runs its tests
-in user-space.
+Separate your module tests and your author tests. This will lower the number
+of dependencies. Check your Pod syntax, documentation coverage, spelling, and
+minimum perl version requirements in C<xt/>.  Prevent declaring dependencies
+that are only used inC<xt/>. There is no need to check prerequisites when the
+distribution runs its tests in user-space.
 
  t/
  xt/
@@ -87,7 +89,7 @@ history.
 =head1 Dependencies
 
 Every module you use is a module your release will depend on. If a new
-release of such module fails, the likelyhood of your release being
+release of such module fails, the likelihood of your release being
 unable to install increases. So only use modules that you need. Each
 dependency should be well-considered.
 
@@ -111,7 +113,8 @@ convenience modules should only be used in (local) perl scripts and
 not in CPAN modules, so please do not add additional dependencies
 on modules/pragma's like L<sanity|https://metacpan.org/pod/sanity>,
 L<Modern::Perl|https://metacpan.org/pod/Modern::Perl>, common::sense,
-or L<nonsense|https://metacpan.org/pod/nonsense>.
+L<exact|https://metacpan.org/pod/exact>, or
+L<nonsense|https://metacpan.org/pod/nonsense>.
 
 However useful they might be in your own working environment and
 force you into behaving well, adding them as a requirement to a
@@ -122,15 +125,15 @@ targeted systems and add a chance to break.
 There is no problem with you using those in your own (non-CPAN)
 scripts and modules, but please do not add needless dependencies.
 
-=over
+L<Test::Prereq|https://metacpan.org/pod/Test::Prereq> is a fine module to
+test your dependencies, but please do not ship it in a test-file on C<t/>.
 
-=item - L<Test::Prereq|https://metacpan.org/pod/Test::Prereq>
-
-=back
-
-Finally, make sure all your dependencies are declared in your META
-structure, so all CPAN clients know what to do before your module
-can be tested.
+Finally, make sure all your dependencies are declared in your META structure,
+so all CPAN clients know what to do before your module can be tested. META
+files are preferably I<not> created manually, but generated by authoring tools
+like L<ExtUtils::MakeMaker|https://metacpan.org/pod/ExtUtils::MakeMaker>,
+L<Dist::Zilla|https://metacpan.org/pod/Dist::Zilla>, or
+L<App::ModuleBuildTiny|https://metacpan.org/pod/App::ModuleBuildTiny> etc.
 
    "prereqs"        : {
      "build"        : {
@@ -161,9 +164,12 @@ users. That would mean that your distribution cannot be used either.
 The reverse is also true: if your release has a more restrictive license than
 most releases on CPAN, it may lead to others avoiding depending on your code.
 
+The perl/perl_5 licence is a reasonable default if you do not have a preferred
+license.
+
 =head1 Documentation
 
-Make sure that you have a clear, consice, and short SYNOPSIS section. This
+Make sure that you have a clear, concise, and short SYNOPSIS section. This
 section should show the most important code as simple and clear as possible.
 If you have 3500 methods in your class, do not list all of the there. Just
 show how to create the object and show the 4 methods that a beginner would
@@ -181,19 +187,37 @@ Make sure your pod is correct and can also be parsed by the pod-modules in
 the lowest version of perl you support (or mention that you need at least
 version whatever to read the pod as intended).
 
+The web is dynamic and some (external) references might seize to exist not
+telling you, so checking links used in your documentation once in a while
+might hint you to updated sites.
+
 =over
 
 =item - L<Test::Pod|https://metacpan.org/pod/Test::Pod>
 
 =item - L<Test::Pod::Coverage|https://metacpan.org/pod/Test::Pod::Coverage>
 
+=item - L<Test::Pod::Links|https://metacpan.org/pod/Test::Pod::Links>
+
 =back
 
+=head1 Neutrality
+
+Do not use offensive or political statements anywhere in your code,
+your documentation, or your changelog(s). No one gains from statements
+about certain operating system(s), editor(s), president(s) or whatever
+are not to your liking. Make neutral claims about not being able to
+test your module on system X instead of saying system X should die a
+horrible death.
+
+Do not use profane language. Do not promote any deity. A religion to one
+might be an insult to others. Keep neutral.
+
 =head1 Spelling
 
 Not every developer is of native English tongue. And even if, they
 also make (spelling) mistakes. There are enough tools available to
-prevent public display of misspellings and typoes. Use them.
+prevent public display of misspellings and typos. Use them.
 
 It is a good plan to have someone else proofread your documentation.
 If you can, ask three readers: one who knows about what the module is
@@ -206,7 +230,7 @@ documentation as weird, unclear, or even plain wrong.
 
 =item - L<pod-spell-check|scripts/pod-spell-check>
 
-=item - L<Pod::Aspell|https://metacpan.org/pod/Pod::Aspell>
+=item - L<Pod::Spelling::Aspell|https://metacpan.org/pod/Pod::Spelling::Aspell>
 
 =item - L<Pod::Escapes|https://metacpan.org/pod/Pod::Escapes>
 
@@ -261,7 +285,7 @@ Remove dead code. It is in your (git) repository anyway.
 
 =over
 
-=item - L<Test::Perl::Critic::TooMuchCode|https://metacpan.org/pod/Test::Perl::Critic::TooMuchCode>
+=item - L<Perl::Critic::TooMuchCode|https://metacpan.org/pod/Perl::Critic::TooMuchCode>
 
 =back
 
@@ -317,6 +341,11 @@ Do not guess. It is easy to check with
 
 =head1 Multiple perl versions
 
+If you host your perl code on github, you can integrate the services of
+L<Travis|https://travis-ci.org>.
+Read L<their instructions|https://docs.travis-ci.com/user/languages/perl/>
+on how to set up for multiple perl versions and or (environment) options.
+
 If you have multiple perls installed on your system, test your module or
 release with all of the versions that you claim to support before doing the
 release. Best would be to test with a threaded perl and a non-threaded perl.
@@ -430,6 +459,12 @@ of that to prevent unhappy users.
   Congratulations for building a 'perfect' distribution!
   $
 
+Other that doing all these tests I<before> you upload to CPAN, there are some
+awesome metrics available on L<cpants|https://cpants.cpanauthors.org/> that
+trigger I<after> you have uploaded to CPAN.
+L<This|https://cpants.cpanauthors.org/> also shows more metrics and has lots
+of good L<documentation for the kwalitee indicators|https://cpants.cpanauthors.org/kwalitee>.
+
 =head1 Clean dist
 
 Some problems only surface when you do a C<make clean> or C<make distclean>.
@@ -451,10 +486,38 @@ Check L<MANIFEST|./MANIFEST> and L<MANIFEST.skip|./MANIFEST.skip> are complete.
 
 =back
 
+  $ perl -MTest::DistManifest -we'manifest_ok'
+  1..4
+  ok 1 - Parse MANIFEST or equivalent
+  ok 2 - All files are listed in MANIFEST or skipped
+  ok 3 - All files listed in MANIFEST exist on disk
+  ok 4 - No files are in both MANIFEST and MANIFEST.SKIP
+
+=head1 File naming
+
+Do not make it hard for people and modules to use the files in your
+distribution by using spaces and special characters in file names. Also try
+to not use overly long names and deep directory structures.
+
+If spaces or weird characters in file or folder names are required by your
+module and/or your test cases, consider creating these files from the test
+itself and cleaning them up when the test is done.
+
+=over
+
+=item - L<Test::Portability::Files|https://metacpan.org/pod/Test::Portability::Files>
+
+=back
+
+  $ perl -MTest::More -MTest::Portability::Files -w \
+    -e 'options (all_tests => 1);' \
+    -e 'options (test_dos_length => 0);' \
+    -e 'run_tests ();'
+
 =head1 Code style consistency
 
 Add a L<CONTRIBUTING.md|./CONTRIBUTING.md> or similar file to guide others to
-consistency that will match L<I<your> style|http://tux.nl/style.html> (or, in
+consistency that will match L<I<your> style|https://tux.nl/style.html> (or, in
 case of joint effort, the style as agreed upon by the developers).
 
 There are helper modules to enforce a style (given a configuration) or try
@@ -547,10 +610,13 @@ Make sure it is a versioning system that increments
 
 =back
 
-=head1 Changelog
+=head1 Changes
 
-Make sure your L<ChangeLog|./ChangeLog> or Changes file is up-to-date. Your
-release procedure might check the most recent mentioned date in that
+Make sure your L<Changes|./Changes> or ChangeLog file is up-to-date. Your
+release procedure might check the most recent mentioned date in that. At
+least every release should have an entry. Put the most recent change(s)
+on top (sort in reverse date order), so people can easily spot the most
+recent change(s).
 
 =over
 
@@ -598,7 +664,7 @@ configuration files or set up databases, that should be mentioned too.
 
 =head1 Tickets
 
-If your module is on [github][https://github.com] or similar, regularly check
+If your module is on L<github|https://github.com> or similar, regularly check
 on submitted issues and deal with them: either explain why it is not an issue
 or comment with alternatives or even better: this has been fixed now.
 Additionally, you should check on possible forks of your code and check the
@@ -607,7 +673,30 @@ you could use to improve your code. If the changes they made are already taken
 into your own code, or your code offers a (better) alternative to their change
 you could comment on their commits with additional information.
 
-Likewise if you use [RT][https://rt.perl.org] as bug tracker.
+Likewise if you use L<RT|https://rt.perl.org> as bug tracker.
+
+If any ticket is entered as a vulnerability issue, be sure to make clear in
+the feedback to that issue that it is indeed a security issue and how you
+dealt with it or that you do/did not acknowledge this as a vulnerability, but
+as a (plain/simple) bug and deal with at with the appropriate actions.
+
+Whatever you choose, make it clear in your META information, so the link to
+issues on L<metacpan|https://metacpan.org/> points to the correct location.
+
+ META.yml
+
+================================================================================
+ resources:
+  bugtracker: https://github.com/Tux/Release-Checklist/issues
+
+ META.json
+
+================================================================================
+ "resources" : {
+   "bugtracker" : {
+     "web" : "https://github.com/Tux/Release-Checklist/issues"
+     }
+   }
 
 =head1 Downriver
 
@@ -620,12 +709,12 @@ if the new release would cause the other module(s) to break.
 L<used_by.pl|./scripts/used-by.pl> will check the depending modules with the
 upcoming version.
 
-Of course it is imposible to cover every possible situation here. The DarkPAN
+Of course it is impossible to cover every possible situation here. The DarkPAN
 (uses of your module beyond what is registered on CPAN) is huge.
 
 =head1 LICENSE
 
-Copyright (C) 2015-2018 H.Merijn Brand.  All rights reserved.
+Copyright (C) 2015-2020 H.Merijn Brand.  All rights reserved.
 
 This library is free software;  you can redistribute and/or modify it under
 the same terms as Perl itself.
